<?php

/**
 * Plugin Name: Affiliate WP Simple Pay Integration
 * Plugin URI: https://www.tipsandtricks-hq.com/wordpress-affiliate/wp-simple-pay-stripe-affiliate-platform-integration-1354
 * Description: Addon for integrating affiliate platform with the WP Simple Pay for Stripe Plugin.
 * Version: 1.2
 * Author: Tips and Tricks HQ
 * Author URI: https://www.tipsandtricks-hq.com/
 * Requires at least: 3.0
 */

if (!defined('ABSPATH')){
    exit;
}

/******************************/
/* WP Simple Pay free Version */
/******************************/

// Takes the $charge_response as a parameter so you can pull information from the charge
// For charge response info see: https://stripe.com/docs/api#charge_object
function affiliate_wpsimplepaystripe_after_charge( $charge_response ) {
    // Useful for adding additional functionality after the charge is complete
    // For example something like storing the transaction ID in the database if you need to
    wp_affiliate_log_debug('WP Simple Pay for Stripe integration - sc_after_charge hook triggered.', true);   
    
    $amount = $charge_response->amount;//Sale Amount
    $amount = round(($amount/100), 2);//Get amount to the traditional value with 2 decimal places.
    $order_id = $charge_response->id;//Transaction ID
    $reference = '';
    
    //Get the email address from the source parameter
    $source = $charge_response->source;
    $source_array = $source->__toArray(true);
    $email = $source_array['name'];//Email address
    
    //Optional parameter
    $ip_address = $charge_response->client_ip;    
    $receipt_number = $charge_response->receipt_number;
    $receipt_email = $charge_response->receipt_email;
    $stripe_customer_id = $charge_response->customer;
    
    $ap_id = $_COOKIE['ap_id'];
    if(empty($ap_id) && !empty($ip_address)){
        wp_affiliate_log_debug("WP Simple Pay for Stripe integration - Checking affiliate ID using customer IP address.", true);
        $ap_id = wp_aff_get_referrer_id_from_ip_address($ip_address);
    }
    if (empty($ap_id)) {
        wp_affiliate_log_debug("WP Simple Pay for Stripe integration - affiliate ID is not present. This customer was not sent by an affiliate.", true);
        return;
    }
    wp_affiliate_log_debug('WP Simple Pay for Stripe integration - Amount: '.$amount.', Order ID: '.$order_id.', Email: '.$email.', ap_id: '. $ap_id, true); 
    
    wp_aff_award_commission_unique($ap_id, $amount, $order_id, $reference, $email);
    wp_affiliate_log_debug("WP Simple Pay for Stripe integration - Commission awarded!", true);
}
add_action( 'sc_after_charge', 'affiliate_wpsimplepaystripe_after_charge' );
/**********************************/
/* End WP Simple Pay free Version */
/**********************************/

/******************************/
/* WP Simple Pay Pro Version */
/******************************/

// Takes the $charge_response as a parameter so you can pull information from the charge
// For charge response info see: https://stripe.com/docs/api#charge_object
function affiliate_wpsimplepaystripe_charge_created( $charge_response, $metadata ) {
    // Useful for adding additional functionality after the charge is complete
    // For example something like storing the transaction ID in the database if you need to
    wp_affiliate_log_debug('WP Simple Pay Pro integration - simpay_charge_created hook triggered.', true);   
    
    $amount = $charge_response->amount;//Sale Amount
    $amount = round(($amount/100), 2);//Get amount to the traditional value with 2 decimal places.
    $order_id = $charge_response->id;//Transaction ID
    $reference = '';
    
    //Get the email address from the source parameter
    $source = $charge_response->source;
    $source_array = $source->__toArray(true);
    $email = $source_array['name'];//Email address
    
    //Optional parameter
    $ip_address = $charge_response->client_ip;    
    $receipt_number = $charge_response->receipt_number;
    $receipt_email = $charge_response->receipt_email;
    $stripe_customer_id = $charge_response->customer;
    
    $ap_id = $_COOKIE['ap_id'];
    if(empty($ap_id) && !empty($ip_address)){
        wp_affiliate_log_debug("WP Simple Pay Pro integration - Checking affiliate ID using customer IP address.", true);
        $ap_id = wp_aff_get_referrer_id_from_ip_address($ip_address);
    }
    if (empty($ap_id)) {
        wp_affiliate_log_debug("WP Simple Pay Pro integration - affiliate ID is not present. This customer was not sent by an affiliate.", true);
        return;
    }
    wp_affiliate_log_debug('WP Simple Pay Pro integration - Amount: '.$amount.', Order ID: '.$order_id.', Email: '.$email.', ap_id: '. $ap_id, true); 
    
    wp_aff_award_commission_unique($ap_id, $amount, $order_id, $reference, $email);
    wp_affiliate_log_debug("WP Simple Pay Pro integration - Commission awarded!", true);
}
add_action( 'simpay_charge_created', 'affiliate_wpsimplepaystripe_charge_created' ,10, 2 );
/******************************/
/* End simple pay pro version */
/******************************/